%define gettext_package dbus
%define dbus_user_uid           101

Distribution:	CCux
Packager:  	Christian Metzen <metzench@ccux-linux.de>

Summary:   	D-BUS message bus
Name:      	dbus
Version:   	1.2.3
Release:   	1
Epoch:		1
License: 	AFL/GPL
URL:		http://www.freedesktop.org/software/dbus/
Group:     	System/Libraries          
Source0: 	dbus-%{version}.tar.gz
Source1: 	messagebus.init
Source2: 	00-start-message-bus.sh
BuildRoot: 	%{_tmppath}/%{name}-buildroot
BuildRequires:	expat-devel libxml2-devel python Pyrex
BuildRequires:	libcap-devel libX11-devel
Requires:	shadow
Requires: 	chkconfig
Prereq(pre): /usr/sbin/groupadd /usr/sbin/useradd

%description
D-BUS is a system for sending messages between applications. It is
used both for the systemwide message bus service, and as a
per-user-login-session messaging facility.

%package devel
Summary: 	Libraries and headers for D-BUS
Group: 		System/Libraries
Requires: 	%name = %{epoch}:%{version}-%{release}

%description devel
Headers and static libraries for D-BUS.

%package x11
Summary: 	X11-requiring add-ons for D-BUS
Group: 		System/Libraries
Requires: 	%name = %{epoch}:%{version}-%{release}

%description x11
D-BUS contains some tools that require Xlib to be installed, those are
in this separate package so server systems need not install X.

%pre
if [ $1 -eq 1 ]; then
    # Add the "dbus" user
    /usr/sbin/useradd -c 'System message bus' -u %{dbus_user_uid} -s /sbin/nologin -d '/' dbus 2> /dev/null || :
fi

%post
/sbin/ldconfig
/sbin/chkconfig --add messagebus 
/sbin/chkconfig messagebus reset
/bin/dbus-uuidgen --ensure

%preun
if [ $1 = 0 ]; then
    /sbin/chkconfig --del messagebus
fi

%postun
if [ $1 -eq 0 ]; then
    /usr/sbin/userdel dbus &>/dev/null || :
fi
ldconfig

%prep
%setup -n dbus-%{version}
/bin/chmod 0644 COPYING ChangeLog NEWS

%build
export CFLAGS='-O2 -march=i686 -pipe -fomit-frame-pointer'
export CXXFLAGS=$CFLAGS

COMMON_ARGS="--disable-libaudit --enable-selinux=no --with-init-scripts=redhat --with-system-pid-file=%{_localstatedir}/run/messagebus.pid --with-dbus-user=%{dbus_user_uid} --libdir=/%{_libdir} --bindir=/bin --sysconfdir=/etc --exec-prefix=/"
### this is some crack because bits of dbus can be 
### smp-compiled but others don't feel like working
function make_fast() {
        ### try to burn through it with SMP a couple times
        make %{?_smp_mflags} || true
        make %{?_smp_mflags} || true

        ### then do a real make and don't ignore failure
        DBUS_VERBOSE=1 make
}

#### Build once with tests to make check
%configure $COMMON_ARGS --enable-tests=yes --enable-verbose-mode=yes --enable-asserts=yes --libexecdir=/lib/dbus-1 --enable-inotify
make_fast

#keep debug mode for now.
exit 0

#### Clean up and build again 
make clean 

%configure $COMMON_ARGS --disable-tests --disable-verbose-mode --disable-asserts --libexecdir=/lib/dbus-1 --enable-inotify
make

%install
rm -rf %{buildroot}

make install DESTDIR=$RPM_BUILD_ROOT

mkdir -p $RPM_BUILD_ROOT/%{_libdir}/pkgconfig

#change the arch-deps.h include directory to /usr/lib[64] instead of /lib[64]
#sed -e 's@-I${libdir}@-I${prefix}/%{_lib}@' $RPM_BUILD_ROOT/%{_libdir}/pkgconfig/dbus-1.pc > $RPM_BUILD_ROOT/%{_libdir}/pkgconfig/dbus-1.pc
#rm -f $RPM_BUILD_ROOT/%{_lib}/pkgconfig/dbus-1.pc

mkdir -p $RPM_BUILD_ROOT/%{_bindir}
mv -f $RPM_BUILD_ROOT/bin/dbus-launch $RPM_BUILD_ROOT/%{_bindir}
#mkdir -p $RPM_BUILD_ROOT/%{_libdir}/dbus-1.0/include/
#mv -f $RPM_BUILD_ROOT/%{_lib}/dbus-1.0/include/* $RPM_BUILD_ROOT/%{_libdir}/dbus-1.0/include/


install -m 755 %{SOURCE1} $RPM_BUILD_ROOT%_sysconfdir/rc.d/init.d/messagebus
install -D -m755 %{SOURCE2} %{buildroot}%{_sysconfdir}/X11/xinit/xinitrc.d/00-start-message-bus.sh

mkdir -p $RPM_BUILD_ROOT/var/lib/dbus

%files
%defattr(-,root,root)

%doc COPYING ChangeLog NEWS

%dir %_sysconfdir/dbus-1
%config %_sysconfdir/dbus-1/*.conf
%config %_sysconfdir/rc.d/init.d/*
%dir %_sysconfdir/dbus-1/system.d
%dir %_sysconfdir/dbus-1/session.d
%dir %_localstatedir/run/dbus
%dir /%_libdir/dbus-1.0
/bin/dbus-daemon
/bin/dbus-send
/bin/dbus-cleanup-sockets
/bin/dbus-monitor
/bin/dbus-uuidgen
%_libdir/*dbus-1*.so.*
%_mandir/man*/dbus-cleanup-sockets.1.gz
%_mandir/man*/dbus-daemon.1.gz
%_mandir/man*/dbus-monitor.1.gz
%_mandir/man*/dbus-send.1.gz
%_mandir/man*/dbus-uuidgen.1.gz
%dir %_datadir/dbus-1
%_datadir/dbus-1/services
%_datadir/dbus-1/system-services
/var/lib/dbus
%attr(4750,root,dbus) /%{_lib}/dbus-1/dbus-daemon-launch-helper

%files x11
%defattr(-,root,root)
%_bindir/dbus-launch
%_datadir/man/man*/dbus-launch.1.gz
%{_sysconfdir}/X11/xinit/xinitrc.d/00-start-message-bus.sh

%files devel
%defattr(-,root,root)
%_libdir/lib*.so
%_libdir/dbus-1.0/include/
%_libdir/pkgconfig/dbus-1.pc
%_includedir/*
%_libdir/*.a
%_libdir/*.la

%clean
rm -rf $RPM_BUILD_ROOT

%changelog
* Thu Aug 14 2008 Karsten Brockmann <arcam@ccux-linux.de> 1:1.2.3-1
- version update
* Sun Apr 13 2008 Karsten Brockmann <arcam@ccux-linux.de> 1:1.2.1-1
- version update
* Tue Mar 04 2008 Christian Metzen <metzench@ccux-linux.de> 1:1.1.20-3
- add start-message-bus.sh to x11 package, unneccessary to include dbus-launch in desktop startscripts
* Sat Mar 01 2008 Karsten Brockmann <arcam@ccux-linux.de> 1:1.1.20-2
- enabled inotify
* Sat Mar 01 2008 Karsten Brockmann <arcam@ccux-linux.de> 1:1.1.20-1
- version update
* Tue Nov 27 2007 Christian Metzen <metzench@ccux-linux.de> 1:1.1.2-4
- start dbus earlier / wpa_supplicant, removed outdated sources
* Mon Nov 26 2007 Christian Metzen <metzench@ccux-linux.de> 1:1.1.2-3
- modified initscript
* Mon Nov 26 2007 Christian Metzen <metzench@ccux-linux.de> 1:1.1.2-2
- added missing directory, moved libexecdir
* Sat Nov 23 2007 Christian Metzen <metzench@ccux-linux.de> 1:1.1.2-1
- Version update
* Sat Jun 23 2007 Karsten Brockmann <arcam@ccux-linux.de> 1:1.0.2-3
- fixed machine-id generation
* Sun Feb 11 2007 Karsten Brockmann <arcam@ccux-linux.de> 1:1.0.2-2
- removed compatibility symlinks
* Sat Jan 20 2007 Karsten Brockmann <arcam@ccux-linux.de> 1:1.0.2-1
- Version update
* Sat Jan 20 2007 Christian Metzen <metzench@ccux-linux.de> 1:0.94-4
- fixed chkconfig call
* Sat Jan 20 2007 Christian Metzen <metzench@ccux-linux.de> 1:0.94-3
- fixed init script, stopping before filesystems get mounted read only
* Fri Nov 17 2006 Christian Metzen <metzench@ccux-linux.de> 1:0.94-2
- back to 0.94 for now
* Mon Nov 13 2006 Karsten Brockmann <arcam@ccux-linux.de> 1.0.0-1
- Version update
* Sun Oct 22 2006 Karsten Brockmann <arcam@ccux-linux.de> 0.94-1
- Version update
* Fri Sep 29 2006 Karsten Brockmann <arcam@ccux-linux.de> 0.93-5
- fixed dbus-1.pc pkgconfig file
* Thu Sep 28 2006 Karsten Brockmann <arcam@ccux-linux.de> 0.93-4
- moved libraries back to /usr/lib
* Thu Sep 28 2006 Christian Metzen <metzench@ccux-linux.de> 0.93-3
- readded .a and .la files
* Thu Sep 28 2006 Christian Metzen <metzench@ccux-linux.de> 0.93-2
- added compat symlink, modified start script
* Thu Sep 28 2006 Christian Metzen <metzench@ccux-linux.de> 0.93-1
- Version update
* Thu Sep 21 2006 Karsten Brockmann <arcam@ccux-linux.de> 0.50-6
- rebuilt against python 2.5
* Sun Apr 09 2006 Christian Metzen <metzench@ccux-linux.de> 0.50-5
- fixed minor bug
* Sat Mar 25 2006 Karsten Brockmann <arcam@ccux-linux.de> 0.50-4
- added python bindings package
* Wed Nov 16 2005 Christian Metzen <metzench@ccux-linux.de> 0.50-3
- New initscript
* Wed Oct 26 2005 Christian Metzen <metzench@ccux-linux.de> 0.50-2
- Fixed small bug in initscript
* Tue Oct 25 2005 Christian Metzen <metzench@ccux-linux.de> 0.50-1
- Version update
* Sat Apr 02 2005 Christian Metzen <metzench@ccux-linux.de> 0.23.4-1
- Version update to 0.23.4
* Fri Mar 25 2005 Christian Metzen <metzench@ccux-linux.de> 0.23-5
- Recompilation against QT 3.3.4
* Fri Jan 28 2005 Christian Metzen <metzench@ccux-linux.de> 0.23-4
- Added default Runlevels, more CCux specific Configs
* Wed Jan 25 2005 Christian Metzen <metzench@ccux-linux.de> 0.23-3
- Re-Added CFLAGS, fixed User Addition
* Wed Jan 25 2005 Christian Metzen <metzench@ccux-linux.de> 0.23-2
- Modified Startscript, Removed CFLAGS
* Wed Jan 25 2005 Christian Metzen <metzench@ccux-linux.de> 0.23-1
- Initial Release
